@@ -18,7 +18,9 @@ from . import GlobalOptions
     type=click.Choice(["auto", "aws-okta", "saml2aws"]),
     help="the SAML client type to use",
 )
-@click.option("--debug", is_flag=True, help="enable verbose debugging")
+@click.option(
+    "--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG"
+)
 @resource_option
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @setup_segment(write_key=SegmentWriteKey)
