@@ -61,7 +61,14 @@ class TargetNotConnected(CliErrorWithHint):
         super().__init__(
             "The instance you tried to SSH into is not connected to AWS Session Manager.",
             "Ask your Sym administrator if they've set up Session Manager.",
-            report=True,
+        )
+
+
+class AccessDenied(CliErrorWithHint):
+    def __init__(self) -> None:
+        super().__init__(
+            "You don't have access to connect to this instance.",
+            "Have you requested access?",
         )
 
 
@@ -82,11 +89,11 @@ class FailedSubprocessError(CliError):
 
 
 class WrappedSubprocessError(CliError):
-    def __init__(self, wrapped, hint) -> None:
+    def __init__(self, wrapped, hint, **kwargs) -> None:
         messages = [
             f"Cannot run {wrapped.cmd[0]} [{wrapped.returncode}]",
             f"Hint: {hint}",
             f"\nThe original error was:",
             wrapped.stderr,
         ]
-        super().__init__("\n".join(messages))
+        super().__init__("\n".join(messages), **kwargs)
