@@ -1,12 +1,17 @@
-from typing import Tuple
+from typing import Optional, Tuple
 
 from ..decorators import intercept_errors, run_subprocess
 from ..helpers.params import get_ssh_user
 from ..helpers.ssh import SSHKey
+from ..saml_clients.aws_profile import AwsProfile
 
 
 def run_ansible(
-    client: "SAMLClient", command: Tuple[str, ...], binary: str = "ansible"
+    client: "SAMLClient",
+    command: Tuple[str, ...],
+    ansible_aws_profile: Optional[str],
+    ansible_sym_resource: Optional[str],
+    binary: str = "ansible",
 ):
     ssh_args = " ".join(
         [
@@ -14,6 +19,12 @@ def run_ansible(
             f'-o ProxyCommand="sh -c \\"sym ssh-session-with-key {client.resource} --host %h --port %p\\""',
         ]
     )
+
+    if ansible_aws_profile:
+        client = client.clone(klass=AwsProfile, resource=ansible_aws_profile)
+    elif ansible_sym_resource:
+        client = client.clone(resource=ansible_sym_resource)
+
     client.exec(
         binary,
         *command,
