@@ -25,7 +25,7 @@ def intercept_boto_errors(f):
     @wraps(f)
     def wrapped(*args, **kwargs):
         try:
-            f(*args, **kwargs)
+            return f(*args, **kwargs)
         except ClientError as err:
             if UnauthorizedError.search(str(err)):
                 raise BotoError(
