@@ -67,22 +67,16 @@ PARAMS: Dict[str, OrgParams] = {
     },
     "sym": {
         "resource_env_var": "ENVIRONMENT",
-        "ssh_user": "ssm-user",
+        "ssh_user": "ubuntu",
         "domain": "symops.io",
         "aws_okta_params": {},
         "saml2aws_params": {"mfa": "Auto"},
         "profiles": {
-            "chris": Profile(
-                display_name="Chris",
+            "test": Profile(
+                display_name="Test",
                 region="us-east-1",
-                arn="arn:aws:iam::185243338273:role/SSMDemo",
-                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oaizjxdwPw8eoNCm4x6/272",
-            ),
-            "jon": Profile(
-                display_name="Jon",
-                region="us-east-1",
-                arn="arn:aws:iam::838419636750:role/JonSSMDemo",
-                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oakt491rxntIE1bx4x6/272",
+                arn="arn:aws:iam::838419636750:role/SSMTestRole",
+                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oaqadixzIIdZqbTx4x6/272",
             ),
         },
     },
