@@ -5,13 +5,14 @@ from textwrap import dedent
 from typing import Sequence
 
 from ..decorators import intercept_errors, run_subprocess
-from ..errors import TargetNotConnected, WrappedSubprocessError
+from ..errors import AccessDenied, TargetNotConnected, WrappedSubprocessError
 from ..helpers.boto import send_ssh_key
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
 
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
 TargetNotConnectedPattern = re.compile("TargetNotConnected")
+AccessDeniedPattern = re.compile("AccessDeniedException")
 
 SSHConfig = SymConfigFile("ssh/config")
 SSHKey = SymConfigFile("ssh/key")
@@ -59,24 +60,26 @@ def start_ssh_session(
     except CalledProcessError as err:
         if MissingPublicKeyPattern.search(err.stderr):
             Config.touch_instance(instance, error=True)
-        raise WrappedSubprocessError(
-            err, f"Does the user ({get_ssh_user()}) exist on the instance?"
-        ) from err
+            raise WrappedSubprocessError(
+                err, f"Does the user ({get_ssh_user()}) exist on the instance?"
+            ) from err
+        # If the ssh key path is cached then this doesn't get intercepted in ensure_ssh_key
+        elif TargetNotConnectedPattern.search(err.stderr):
+            raise TargetNotConnected() from err
+        elif AccessDeniedPattern.search(err.stderr):
+            raise AccessDenied() from err
+        else:
+            raise WrappedSubprocessError(
+                err, f"Contact your Sym administrator.", report=True
+            ) from err
     else:
         Config.touch_instance(instance)
 
 
 @intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
 def ensure_ssh_key(client, instance: str, port: int):
-    instance_config = Config.get_instance(instance)
-
-    if SSHKey.path.exists():
-        last_connect = instance_config.get("last_connection")
-        if last_connect and datetime.now() - last_connect < timedelta(days=1):
-            client.dprint(f"Skipping remote SSH key check for {instance}")
-            return
-    else:
-        gen_ssh_key(SSHKey, capture_output_=True)
+    # Write the SSH Config first, we need to do this regardles of whether the
+    # SSH Key is present on the box.
 
     # fmt: off
     SSHConfig.put(dedent(
@@ -94,6 +97,16 @@ def ensure_ssh_key(client, instance: str, port: int):
     ))
     # fmt: on
 
+    instance_config = Config.get_instance(instance)
+
+    if SSHKey.path.exists():
+        last_connect = instance_config.get("last_connection")
+        if last_connect and datetime.now() - last_connect < timedelta(days=1):
+            client.dprint(f"Skipping remote SSH key check for {instance}")
+            return
+    else:
+        gen_ssh_key(SSHKey, capture_output_=True)
+
     try:
         _start_background_ssh_session(
             client, instance, port, "exit", capture_output_=True
