@@ -3,6 +3,7 @@ from os import fchmod
 from pathlib import Path
 from typing import Iterator, Optional, TextIO
 
+from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
 
 
@@ -38,4 +39,5 @@ class Sandbox:
     @contextmanager
     def push_xdg_config_home(self) -> Iterator[None]:
         with push_env("XDG_CONFIG_HOME", str(self.path / ".config")):
+            Config.reset()
             yield
