@@ -16,7 +16,7 @@ def test_saml2aws(
             saml2aws.exec("aws", "ssm", "start-session", target="i-0123456789abcdef")
     capture_command.assert_command(
         f"saml2aws --config {saml2aws.saml2aws_cfg} --idp-account sym login",
-        f"saml2aws --config {saml2aws.saml2aws_cfg} --idp-account sym exec -- aws ssm start-session --target i-0123456789abcdef",
+        f"saml2aws --config {saml2aws.saml2aws_cfg} --idp-account sym exec -- 'aws ssm start-session --target i-0123456789abcdef'",
     )
 
 
